@@ -93,7 +93,7 @@ _OptionalStatementDataTypeDef = TypedDict(
         "QueryString": str,
         "SecretArn": str,
         "StatementName": str,
-        "Status": Literal["ABORTED", "ALL", "FAILED", "FINISHED", "PICKED", "STARTED", "SUBMITTED"],
+        "Status": Literal["SUBMITTED", "PICKED", "STARTED", "FINISHED", "ABORTED", "FAILED", "ALL"],
         "UpdatedAt": datetime,
     },
     total=False,
@@ -124,13 +124,14 @@ _OptionalDescribeStatementResponseTypeDef = TypedDict(
         "DbUser": str,
         "Duration": int,
         "Error": str,
+        "HasResultSet": bool,
         "QueryString": str,
         "RedshiftPid": int,
         "RedshiftQueryId": int,
         "ResultRows": int,
         "ResultSize": int,
         "SecretArn": str,
-        "Status": Literal["ABORTED", "ALL", "FAILED", "FINISHED", "PICKED", "STARTED", "SUBMITTED"],
+        "Status": Literal["SUBMITTED", "PICKED", "STARTED", "FINISHED", "ABORTED", "FAILED", "ALL"],
         "UpdatedAt": datetime,
     },
     total=False,
